==> manydhcp2.5.2.tar.bz2: manydhcp/savepar/addform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) include "../lang/".$lang."/".$lang.".php";
     else include "../lang/ru/ru.php";

  $title=$titlepage = $TEXT['param_new'];
  if(!isset($button)) $button = $TEXT['btn_add'];
  if(!isset($action)) $action = "add.php";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it_page"><?php echo $TEXT['analiz-tab']; ?></td><td>
<select class="input" name=tip>
  <option value='tbl_logs' selected><?php echo $TEXT['menu-btn5']; ?>
</select>
</td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['param_days']; ?></td><td><input size=20 maxlength=20 type=text name=paramdays >&nbsp;<input type=checkbox name=paramon ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['size-count2']; ?></td><td><input size=20 maxlength=20 type=text name=sizecount >&nbsp;<input type=checkbox name=sizeon ></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' /></td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>

==> manydhcp2.8.2.tar.bz2: manydhcp/savepar/addform.php <==
<?php
  ///////////////////////////////////////////////////
  //2010 (C)
  //Карпухин Павел
  ///////////////////////////////////////////////////

  $lang = substr($_SERVER["HTTP_ACCEPT_LANGUAGE"], 0,2);
  if(is_file ("../lang/".$lang."/".$lang.".php")) {include "../lang/".$lang."/".$lang.".php";}
     else {include "../lang/ru/ru.php";}

  $title = $TEXT['param_new'];
  $button = $TEXT['btn_add'];
  $action = "add.php";

  require_once "../config_a.php";
  require_once "../utils/functions.php";
  require_once "../utils/top_adm.php";

  if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center" >
<tr><td class="bold_it_page"><?php echo $TEXT['analiz-tab']; ?></td><td>
<select class="input" name=tip>
  <option value='tbl_logs' selected><?php echo $TEXT['menu-btn5']; ?>
</select>
</td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['param_days']; ?></td><td><input size=20 maxlength=20 type=text name=paramdays >&nbsp;<input type=checkbox name=paramon ></td></tr>
<tr><td class="bold_it_page"><?php echo $TEXT['size-count2']; ?></td><td><input size=20 maxlength=20 type=text name=sizecount >&nbsp;<input type=checkbox name=sizeon ></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>' /></td></tr>
</table>
</form>
<?php
  require_once "../utils/bottom_adm.php";
?>
